﻿var KretaGridHelper = (function () {
  var kretaGridHelper = function () {};

  kretaGridHelper.getKendoGridData = function (gridId) {
    var grid = $('#' + gridId);
    var gridData = grid.data('kendoGrid');
    return gridData;
  };

  kretaGridHelper.refreshGrid = function (gridName) {
    var gridData = kretaGridHelper.getKendoGridData(gridName);
    if (!CommonUtils.isNullOrUndefined(gridData)) {
      gridData.dataSource.read();
      gridData.refresh();
    }
  };

  kretaGridHelper.refreshGridSearchPanel = function (gridName, formName) {
    var gridData = kretaGridHelper.getKendoGridData(gridName);
    if (!CommonUtils.isNullOrUndefined(gridData)) {
      var query = {
        data: searchPanelReloadGrid(formName),
        page: gridData.dataSource._page,
        pageSize: gridData.dataSource.pageSize(),
        sort: gridData.dataSource.sort(),
        filter: gridData.dataSource.filter()
      };
      gridData.dataSource.query(query);
      gridData.refresh();
    }
  };

  kretaGridHelper.getSearchParameters = function (formName) {
    var result = { data: JSON.stringify($(formName).toObject()) };
    return result;
  };

  kretaGridHelper.refreshGridByFormName = function (gridName, formName) {
    var searchParameterObject =
      kretaGridHelper.getSearchParameterObject(formName);
    if (!CommonUtils.isNull(searchParameterObject)) {
      kretaGridHelper.refreshGridByObject(gridName, searchParameterObject);
    }
  };

  kretaGridHelper.getSearchParameterObject = function (formName) {
    var formElement = $('#' + formName);
    if (!CommonUtils.exists(formElement)) {
      return null;
    }
    var result = formElement.toObject();
    return result;
  };

  kretaGridHelper.getSearchParametersWithoutInputNames = function (
    searchFormName
  ) {
    var data = CommonUtils.JSONparse(
      kretaGridHelper.getSearchParameters('#' + searchFormName).data
    );
    for (var key in data) {
      var k = key + '_input';
      if (data.hasOwnProperty(k)) {
        delete data[k];
      }
    }
    return data;
  };

  kretaGridHelper.refreshGridByObject = function (
    gridName,
    searchParameterObject
  ) {
    var gridData = kretaGridHelper.getKendoGridData(gridName);
    if (!CommonUtils.isNullOrUndefined(gridData)) {
      var data = kretaGridHelper.getSearchParameterData(searchParameterObject);
      gridData.dataSource.read(data);
      gridData.refresh();
    }
  };

  kretaGridHelper.clearGridData = function (gridName) {
    var gridData = kretaGridHelper.getKendoGridData(gridName);
    if (!CommonUtils.isNullOrUndefined(gridData)) {
      var data = [];
      gridData.dataSource.read(data);
      gridData.refresh();
    }
  };

  kretaGridHelper.getSearchParameterData = function (searchParameterObject) {
    var result = {
      data: JSON.stringify(remove_inputProperties(searchParameterObject))
    };
    return result;
  };

  kretaGridHelper.init = function (e) {
    var gridName = e.sender.element.attr('id');
    initSpecColumns(gridName);
    handleDirtyRead(gridName);
    detailGridInit(gridName);

    var grid = $('#' + gridName).data('kendoGrid');
    grid.thead.kendoTooltip({
      filter: 'th[data-gridheadertooltip]',
      content: function (e) {
        var target = e.target;
        return target.data('gridheadertooltip');
      }
    });
  };

  kretaGridHelper.initToolBar = function (e, gridName) {
    if (e.type != 'read') {
      return;
    }
    initPager(e, gridName);
  };

  kretaGridHelper.selectAll = function (sender, gridName) {
    var state = sender.is(':checked');
    $('#' + gridName)
      .find('*[data-selectGroup="' + gridName + '"]')
      .prop('checked', state);
  };

  kretaGridHelper.rowFunctionCall = function (
    sender,
    gridId,
    jsFunction,
    sendSender
  ) {
    sendSender = sendSender || false;
    var parentRow = sender.closest('tr').attr('data-uid');
    var rowData = kretaGridHelper.getGridRowData(gridId, parentRow);
    if (sendSender) {
      jsFunction(sender, rowData);
    } else {
      jsFunction(rowData);
    }
  };

  kretaGridHelper.getRowId = function (sender, gridId) {
    var parentRow = sender.closest('tr').attr('data-uid');
    var rowData = kretaGridHelper.getGridRowData(gridId, parentRow);
    return rowData.ID;
  };

  kretaGridHelper.getRowData = function (sender, gridId) {
    var parentRow = sender.closest('tr').attr('data-uid');
    var rowData = kretaGridHelper.getGridRowData(gridId, parentRow);
    return rowData;
  };

  kretaGridHelper.updateDirtyInputsData = function (gridId) {
    var dirtyRows = getDirtyRows(gridId);
    $.each(dirtyRows, function (i, row) {
      updateRowDataFromInput(row);
    });
  };

  kretaGridHelper.getAllRows = function (gridName) {
    var allRows = kretaGridHelper.getKendoGridData(gridName).dataSource.data();
    $.each(allRows, function (i, row) {
      kretaGridHelper.addInputToRowData(row);
    });
    return allRows;
  };

  kretaGridHelper.getAllRowsWithDataAttribute = function (
    gridName,
    dataAttributes
  ) {
    var allRows = kretaGridHelper.getKendoGridData(gridName).dataSource.data();
    $.each(allRows, function (i, row) {
      addInputAndDataAttributeToRowData(row, dataAttributes);
    });
    return allRows;
  };

  kretaGridHelper.functionCommandCall = function (sender, gridId, jsFunction) {
    var gridData = kretaGridHelper.getKendoGridData(gridId);
    if (!CommonUtils.isNullOrUndefined(gridData)) {
      jsFunction(gridData.dataSource.data());
    }
  };

  kretaGridHelper.getSelectedCheckboxIds = function (gridName) {
    var data = { Items: [] };

    $.each($('td.gridSelectCheckBox input:checkbox'), function (i, v) {
      if ($(v).prop('checked') == true) {
        data.Items.push({ Id: kretaGridHelper.getRowId($(v), gridName) });
      }
    });

    return data;
  };

  kretaGridHelper.getSelectedRowsByGridName = function (gridName) {
    var selectedRows = [];
    $.each(
      $('#' + gridName + ' td.gridSelectCheckBox input:checkbox'),
      function (i, e) {
        if ($(e).prop('checked') == true) {
          var rowId = $(e).closest('tr').attr('data-uid');
          var rowData = kretaGridHelper.getGridRowData(gridName, rowId);
          kretaGridHelper.addInputToRowData(rowData);
          selectedRows.push(rowData);
        }
      }
    );
    return selectedRows;
  };

  kretaGridHelper.getModifiedRows = function (gridName) {
    var dirtyRows = getDirtyRows(gridName);
    $.each(dirtyRows, function (i, row) {
      kretaGridHelper.addInputToRowData(row);
    });
    return dirtyRows;
  };

  kretaGridHelper.haveModifiedRows = function (gridName) {
    if (getDirtyRows(gridName).length > 0) {
      return true;
    }
    return false;
  };

  kretaGridHelper.openAllGrid = function () {
    var plusElements = $('.k-master-row .k-plus');
    var minusElements = $('.k-master-row .k-minus');

    if (plusElements.length > 0) {
      $('.k-master-row .k-plus').click();
    }
    if (minusElements.length > 0) {
      $('.k-master-row .k-minus').click();
    }
  };

  kretaGridHelper.exportGrid = function (
    grid,
    exportFileName,
    customColumnArray,
    customDateColumnWidth,
    popupExport,
    exportHiddenColumns
  ) {
    var exportcolumnurl = $('[data-exportcolumnurl]').data('exportcolumnurl');
    var exportdataurl = $('[data-exportdataurl]').data('exportdataurl');

    if (
      typeof exportcolumnurl !== 'undefined' &&
      typeof exportdataurl !== 'undefined' &&
      (popupExport == false || popupExport == 'undefined')
    ) {
      AjaxHelper.DoPost(exportcolumnurl, null, setExportColumns);
      var customFilterData = '-';
      if ($('#searchForm').length) {
        customFilterData = JSON.stringify($('#searchForm').toObject());
      }

      function setExportColumns(data) {
        var columnsArray = [];
        $.each(data, function (key, value) {
          if (
            customColumnArray !== 'undefined' &&
            customColumnArray.length > 0
          ) {
            if ($.inArray(value.Field, customColumnArray) !== -1) {
              columnsArray.push({
                field: value.Field,
                title: value.Title
              });
            }
          } else {
            columnsArray.push({
              field: value.Field,
              title: value.Title
            });
          }
        });

        var sort = $('#' + grid.id)
          .data('kendoGrid')
          .dataSource.sort();
        var dir = '-';
        var field = '-';
        if (typeof sort !== 'undefined' && sort.length > 0) {
          dir = sort[0].dir;
          field = sort[0].field;
        }

        $.ajax({
          url: exportdataurl,
          data: {
            searchFilter: customFilterData,
            sortColumn: field,
            sortDir: dir
          },
          success: function (data) {
            var exportDiv = $('<div>', { id: 'exportDiv' });
            var dataSource = new kendo.data.DataSource({
              data: data.Data
            });
            dataSource.read();

            var exportGrid = exportDiv.kendoGrid({
              columns: columnsArray,
              excel: { fileName: exportFileName }
            });

            var grid = exportGrid.data('kendoGrid');
            grid.setDataSource(dataSource);
            grid.saveAsExcel();
          }
        });
      }
    } else {
      var exportDiv = $('<div>', { id: 'exportDiv' });
      var columnTemplates = [];
      var hiddenColumnsCount = 0;

      var columns = $('#' + grid.attributes.id.value).data('kendoGrid').columns;
      $.each(columns, function (i, v) {
        v.footerTemplate = null;
        if (exportHiddenColumns) {
          v.hidden = undefined;
        } else if (v.hidden === true) {
          hiddenColumnsCount++;
        }

        if (columns[i].template && columns[i].field != null) {
          columnTemplates.push({
            cellIndex: i - 1,
            template: kendo.template(columns[i].template)
          });
        }
      });

      var exportGrid = exportDiv.kendoGrid({ columns: columns });
      var dataSource = $('#' + grid.attributes.id.value).data(
        'kendoGrid'
      ).dataSource;
      var grid = exportGrid.data('kendoGrid');

      $.each(grid.columns, function (i, v) {
        if (CommonUtils.isNullOrUndefined(customDateColumnWidth)) {
          v.width = null;
        } else {
          v.width = CommonUtils.isNullOrUndefined(v.format)
            ? null
            : customDateColumnWidth;
        }
      });
      grid.setDataSource(dataSource);
      grid.options.excel.fileName = exportFileName;
      grid.options.excel.allPages = true;

      if (popupExport === true) {
        grid.bind('excelExport', function (e) {
          var elem = document.createElement('div');
          for (var i = 1; i < e.workbook.sheets[0].rows.length; i++) {
            var row = e.workbook.sheets[0].rows[i];
            var dataItem = e.data[i - 1];
            for (var j = 0; j < columnTemplates.length; j++) {
              var columnTemplate = columnTemplates[j];
              elem.innerHTML = columnTemplate.template(dataItem);
              if (
                row.cells[columnTemplate.cellIndex - hiddenColumnsCount] !=
                'undefined'
              ) {
                row.cells[columnTemplate.cellIndex - hiddenColumnsCount].value =
                  elem.textContent || elem.innerText || '';
              }
            }
          }
        });
      }
      grid.saveAsExcel();
    }
  };

  kretaGridHelper.exportGridAndSaveAsExcel = function (
    columnsNameAndTitleArray,
    gridDataSource,
    exportFileName
  ) {
    var columnsNameAndTitleArrayConvertedForKendoGrid = [];
    $.each(columnsNameAndTitleArray, function (key, value) {
      columnsNameAndTitleArrayConvertedForKendoGrid.push({
        field: value.Field,
        title: value.Title
      });
    });

    var exportDiv = $('<div>', { id: 'exportDiv' });
    var exportGrid = exportDiv.kendoGrid({
      columns: columnsNameAndTitleArrayConvertedForKendoGrid
    });
    var grid = exportGrid.data('kendoGrid');

    var dataSource = new kendo.data.DataSource({
      data: gridDataSource.Data
    });
    dataSource.read();

    grid.setDataSource(dataSource);

    if (typeof exportFileName === 'undefined') {
      exportFileName = 'Export';
    }
    grid.options.excel.fileName = exportFileName;
    grid.saveAsExcel();
  };

  kretaGridHelper.resetHeaderCheckbox = function (gridName) {
    $('#' + gridName + '_chk').prop('checked', false);
  };

  function initSpecColumns(gridName) {
    var specInput = $('[data-inputParentGrid = "' + gridName + '"]');
    $.each(specInput, function (i, e) {
      eval($(e).children('script').last().html());
      $(e).change(function () {
        inputFieldChange($(this), gridName);
      });
    });

    handleDropdownSpecColumn(gridName);

    var rowCommand = $('[data-rowFunctionParent = "' + gridName + '"]');
    $.each(rowCommand, function (i, e) {
      eval($(e).children('script').last().html());
    });
  }

  function handleDropdownSpecColumn(gridName) {
    var specDropDownInput = $(
      '.gridDropDownList[data-inputParentGrid = "' + gridName + '"]'
    );
    var urls = [];

    $.each(specDropDownInput, function () {
      var url = $(this).data('dropdownurl');
      if (!CommonUtils.isUndefined(url)) {
        var dataReadFunction = null;

        try {
          var stringFunction = $(this).data('readdatahandler');
          if (stringFunction != '') {
            dataReadFunction = new Function(stringFunction);
          }
        } catch (e) {
          console.error(e);
        }
        var dropdownUrl = $.grep(urls, function (item) {
          return item.url == url;
        });
        if (dropdownUrl.length < 1) {
          urls.push({
            element: [{ Id: '#' + $(this).attr('data-uddlId') }],
            url: url,
            dataReadFunction: dataReadFunction,
            dropdownGroupCustomOrder: $(this).attr(
              'data-dropdownGroupCustomOrder'
            )
          });
        } else {
          dropdownUrl[0].element.push({
            Id: '#' + $(this).attr('data-uddlId')
          });
        }
      }
    });

    $.each(urls, function () {
      var e = this.element;
      var dropdownGroupCustomOrder = this.dropdownGroupCustomOrder;
      if (this.dataReadFunction != null) {
        AjaxHelper.DoGet(this.url, this.dataReadFunction(), function (d) {
          setDropdown(d, e, dropdownGroupCustomOrder);
        });
      } else {
        AjaxHelper.DoGet(this.url, {}, function (d) {
          setDropdown(d, e, dropdownGroupCustomOrder);
        });
      }

      function setDropdown(data, elements, dropdownGroupCustomOrder) {
        var useGroup = false;
        var dataSource = new kendo.data.DataSource({
          data: []
        });

        $.each(data, function (i, e) {
          dataSource.fetch(function () {
            if (e.Group != null) {
              dataSource.add({
                Value: e.Value,
                Text: e.Text,
                Group: e.Group,
                SortId: i
              });
              useGroup = true;
            } else if (e.GroupName != null) {
              dataSource.add({
                Value: e.Value,
                Text: e.Text,
                Group: e.GroupName,
                SortId: i
              });
              useGroup = true;
            } else {
              dataSource.add({ Value: e.Value, Text: e.Text });
            }
          });
        });

        if (useGroup) {
          if (typeof dropdownGroupCustomOrder === 'undefined') {
            dataSource.group({ field: 'Group' });
          } else {
            dataSource.group({ field: 'Group', dir: dropdownGroupCustomOrder });
          }
          dataSource.sort({ field: 'SortId', dir: 'asc' });
        }

        $(document).ready(function () {
          $.each(elements, function () {
            var ddl = $(this.Id).data('kendoDropDownList');
            var combo = $(this.Id).data('kendoComboBox');

            if (ddl) {
              ddl.setDataSource(dataSource);
              ddl.value($(this.Id).attr('value'));
            } else if (combo) {
              combo.setDataSource(dataSource);
              combo.value($(this.Id).attr('value'));
            }
          });
        });
      }
    });
  }

  function handleDirtyRead(gridName) {
    var headerRow = $('#' + gridName)
      .find('thead')
      .first();
    var sortColumnHeader = headerRow.find("th[data-role='columnsorter']");
    $.each(sortColumnHeader, function (i, elem) {
      $(elem).unbind('click.kendoGrid');
      $(elem).bindFirst('click.kendoGrid', function (e) {
        dirtyRowConfirm(e, gridName);
      });
    });
  }

  function dirtyRowConfirm(e, gridName) {
    if (getDirtyRows(gridName).length > 0) {
      if (confirm(Globalization.GridAdatvesztesFigyelmeztetes) == false) {
        e.preventDefault();
        e.stopPropagation();
        e.stopImmediatePropagation();
      }
    }
  }

  kretaGridHelper.addInputToRowData = function (rowData) {
    var inputControls = $('[data-uid ="' + rowData.uid + '"]').find(
      '[data-rowInputName]'
    );
    var rowInputs = [];
    $.each(inputControls, function (y, input) {
      var val = '';
      if ($(input).prop('type') === 'checkbox') {
        val = $(input).prop('checked');
      } else if ($(input).attr('data-role') === 'timepicker') {
        val = kendo.toString($(input).data('kendoTimePicker').value(), 'H:mm');
      } else {
        val = $(input).val();
      }
      rowInputs.push({ name: $(input).attr('data-rowInputName'), value: val });
      rowData['ki_' + $(input).attr('data-rowInputName')] = val;
    });
    rowData.input = rowInputs;
  };

  function addInputAndDataAttributeToRowData(rowData, dataAttributes) {
    var rowInputs = [];

    $.each(dataAttributes, function (i, v) {
      var element = $('[data-uid ="' + rowData.uid + '"]').find(
        '[data-' + v + ']'
      );
      var value = $(element).attr('data-' + v);

      if (value === 'null') {
        value = null;
      }

      rowInputs.push({ name: v, value: value });
      rowData['ki_' + v] = value;
    });

    var inputControls = $('[data-uid ="' + rowData.uid + '"]').find(
      '[data-rowInputName]'
    );

    $.each(inputControls, function (y, input) {
      var val = '';
      if ($(input).prop('type') === 'checkbox') {
        val = $(input).prop('checked');
      } else if ($(input).attr('data-role') === 'timepicker') {
        val = kendo.toString($(input).data('kendoTimePicker').value(), 'H:mm');
      } else {
        val = $(input).val();
      }
      rowInputs.push({ name: $(input).attr('data-rowInputName'), value: val });
      rowData['ki_' + $(input).attr('data-rowInputName')] = val;
    });
    rowData.input = rowInputs;
  }

  function updateRowDataFromInput(rowData) {
    var inputControls = $('[data-uid ="' + rowData.uid + '"]').find(
      '[data-rowInputName]'
    );
    $.each(inputControls, function (y, input) {
      var val = '';
      if ($(input).prop('type') === 'checkbox') {
        val = $(input).prop('checked');
      } else if ($(input).attr('data-role') === 'timepicker') {
        val = kendo.toString($(input).data('kendoTimePicker').value(), 'H:mm');
      } else {
        val = $(input).val();
      }
      rowData[$(input).attr('data-rowInputName')] = val;
    });
  }

  function getDirtyRows(gridName) {
    var gridData = kretaGridHelper.getKendoGridData(gridName).dataSource.data();
    var dirty = $.grep(gridData, function (item) {
      return item.dirty;
    });
    return dirty;
  }

  function inputFieldChange(sender, gridName) {
    var parentRow = sender.closest('tr').attr('data-uid');
    var rowData = kretaGridHelper.getGridRowData(gridName, parentRow);
    rowData.dirty = true;
  }

  function searchPanelReloadGrid(formName) {
    var formObject = $('#' + formName).toObject();
    var result = JSON.stringify(remove_inputProperties(formObject));
    return result;
  }

  function remove_inputProperties(object) {
    //TCs: az _input részben a felesleges szöveges érték van, ami ha html kódot tartalmaz, akkor üresen jelenik meg a grid
    var result = {};
    for (var property in object) {
      if (!property.endsWith('_input')) {
        result[property] = object[property];
      }
    }
    return result;
  }

  kretaGridHelper.getGridRowData = function (gridId, rowId) {
    var gridData = kretaGridHelper.getKendoGridData(gridId);
    var rowData = null;
    $.each(gridData.dataSource.data(), function (i, e) {
      if (e.uid == rowId) {
        rowData = e;
        return false;
      }
    });
    return rowData;
  };

  kretaGridHelper.setRowToDirty = function (gridId, id) {
    var gridData = kretaGridHelper.getKendoGridData(gridId);
    $.each(gridData.dataSource.data(), function (i, e) {
      if (parseInt(e.ID) == id) {
        e.dirty = true;
        return false;
      }
    });
  };

  function initPager(responsEvent, gridName) {
    function initBackButton() {
      var button = grid.find('.kendoGrid-Back');
      button.removeClass('k-state-disabled');
      button.unbind('click.kendoGrid');
      if (currentPage <= 1) {
        button.addClass('k-state-disabled');
      } else {
        button.bind('click.kendoGrid', function (e) {
          dirtyRowConfirm(e, gridName);
        });
        button.bind('click.kendoGrid', function () {
          gridData.page(gridData.page() - 1);
        });
      }
    }

    function initNextButton() {
      var button = grid.find('.kendoGrid-Next');
      button.removeClass('k-state-disabled');
      button.unbind('click.kendoGrid');
      if (currentPage >= totalPage) {
        button.addClass('k-state-disabled');
      } else {
        button.bind('click.kendoGrid', function (e) {
          dirtyRowConfirm(e, gridName);
        });
        button.bind('click.kendoGrid', function () {
          gridData.page(gridData.page() + 1);
        });
      }
    }

    function initCounter() {
      var info = grid.find('.kendoGrid-PageInfo');
      var min = (currentPage - 1) * pageSize + 1;
      var max = currentPage * pageSize;
      if (max > total) {
        max = total;
      }
      info.text(
        (isNaN(min) ? 0 : min) + ' - ' + (isNaN(max) ? 0 : max) + ' / ' + total
      );
    }

    function initPageSize() {
      var dropdown = $('#' + gridName + '_PageSize');
      dropdown.unbind('change.kendoGrid');
      dropdown.bind('change.kendoGrid', function () {
        gridData.pageSize($(this).val());
      });
    }

    function hideIfUnnecessary() {
      var pager = grid.find('.k-grid-pager');

      grid.find('span.kendoGrid-PageInfo').hide();

      if (totalPage > 1) {
        pager.find('.k-dropdown').show();
        pager.find('.kendoGrid-Back').show();
        pager.find('.kendoGrid-Next').show();

        grid.find('span.kendoGrid-PageInfo').show();
      } else {
        if (gridData.pageSize() == 100) {
          pager.find('.k-dropdown').hide();
        }
        pager.find('.kendoGrid-Back').hide();
        pager.find('.kendoGrid-Next').hide();

        var pagerInfo = grid.find('span.kendoGrid-PageInfo.mustShowPagerCount');
        if (pagerInfo.length > 0) {
          if (pagerInfo.text().indexOf(' - 0 / 0') === -1) {
            grid.find('span.kendoGrid-PageInfo').show();
          }
        }

        if (
          grid.find('.kendo-gridFunctionKommand').length == 0 &&
          grid.find('.k-i-excel').length == 0 &&
          grid.find('.k-i-pdf').length == 0 &&
          grid.find('span.kendoGrid-PageInfo.mustShowPagerCount').length == 0
        ) {
          grid.find('.k-grid-toolbar').remove();
        }
      }
    }

    var total = responsEvent.response.Total;
    var pageSize = responsEvent.sender._pageSize;
    var currentPage = responsEvent.sender._page;
    var totalPage = Math.ceil(total / pageSize);

    var grid = $('#' + gridName);
    var gridData = kretaGridHelper.getKendoGridData(gridName).dataSource;
    initBackButton();
    initNextButton();
    initCounter();
    initPageSize();
    hideIfUnnecessary();
  }

  function detailGridInit(gridName) {
    if (typeof $('#' + gridName).attr('clientTemplateUrl') !== 'undefined') {
      var gridData = kretaGridHelper.getKendoGridData(gridName);
      gridData.unbind('detailInit');
      gridData.bind('detailInit', function (e) {
        if ($('#' + gridName).attr('clientTemplateWholeDataRow') == 'True') {
          AjaxHelper.DoPost(
            $('#' + gridName).attr('clientTemplateUrl'),
            kretaGridHelper.getGridRowData(gridName, e.data.uid),
            function (data) {
              e.detailCell.append(data);
            }
          );
        } else {
          AjaxHelper.DoPost(
            $('#' + gridName).attr('clientTemplateUrl'),
            {
              Id: e.data.ID
            },
            function (data) {
              e.detailCell.append(data);
            }
          );
        }
      });
    }
  }

  //NOTE: Ezzel szűrjük az export-ot a SearchPanelSideBar-ban lévő property-kkel.
  //Ha null, akkor visszakapjuk az összes elemet a gridben, szűrés nélkül.
  kretaGridHelper.getExportBySearchForm = function (
    gridName,
    url,
    searchFormName
  ) {
    var searchParameters = null;
    if (searchFormName) {
      searchParameters = kretaGridHelper.getSearchParameters(
        `#${searchFormName}`
      );
    }

    kretaGridHelper.getExport(gridName, url, searchParameters);
  };

  //NOTE: Ezzel szűrjük az export-ot már előre elkészített searchParameters objektummal.
  //Figyelni, kell, hogy a c# oldalon benne legyenek a szűrő modelben a searchParameters property-jei!
  //Ha null, akkor üres string-ként adjuk át a searchParameters-t és nem történik semmilyen szűrés.
  kretaGridHelper.getExport = function (gridName, url, searchParameters) {
    if (CommonUtils.isNullOrUndefined(searchParameters)) {
      searchParameters = { data: '' };
    }

    var gridData = kretaGridHelper.getKendoGridData(gridName);
    var params = gridData.dataSource._params();
    var dataSourceRequest = gridData.dataSource.transport.parameterMap(params);
    var data = Object.assign(dataSourceRequest, searchParameters);

    AjaxHelper.DownloadFile(url, data, true);
  };

  return kretaGridHelper;
})();

$.fn.bindFirst = function (name, fn) {
  this.on(name, fn);
  this.each(function () {
    var handlers = $._data(this, 'events')[name.split('.')[0]];
    // take out the handler we just inserted from the end
    var handler = handlers.pop();
    // move it at the beginning
    handlers.splice(0, 0, handler);
  });
};
